@@ -391,6 +391,52 @@ int igraph_adjlist_fprint(const igraph_adjlist_t *al, FILE *outfile) {
   return 0;
 }
 
+#define ADJLIST_CANON_EDGE(from, to, directed) \
+  do {				       \
+    igraph_integer_t temp;	       \
+    if((!directed) && from < to) {     \
+      temp = to;		       \
+      to = from;		       \
+      from = temp;		       \
+    }				       \
+  } while(0);
+
+igraph_bool_t igraph_adjlist_has_edge(igraph_adjlist_t* al, igraph_integer_t from, igraph_integer_t to, igraph_bool_t directed) {
+  igraph_vector_int_t* fromvec;
+  ADJLIST_CANON_EDGE(from, to, directed);
+  fromvec = igraph_adjlist_get(al, from);
+  return igraph_vector_int_binsearch2(fromvec, to);
+
+}
+
+int igraph_adjlist_replace_edge(igraph_adjlist_t* al, igraph_integer_t from, igraph_integer_t oldto, igraph_integer_t newto, igraph_bool_t directed) {
+  igraph_vector_int_t *oldfromvec, *newfromvec;
+  int err1, err2;
+  long int oldpos, newpos;
+  igraph_integer_t oldfrom = from, newfrom = from;
+  ADJLIST_CANON_EDGE(oldfrom, oldto, directed);
+  ADJLIST_CANON_EDGE(newfrom, newto, directed);
+
+  oldfromvec = igraph_adjlist_get(al, oldfrom);
+  newfromvec = igraph_adjlist_get(al, newfrom);
+
+  
+  err1 = igraph_vector_int_binsearch(oldfromvec, oldto, &oldpos);
+  err2 = igraph_vector_int_binsearch(newfromvec, newto, &newpos);
+
+  /* oldfrom -> oldto should exist; newfrom -> newto should not. */
+  if((!err1) || err2)
+    return 1;
+
+  igraph_vector_int_remove(oldfromvec, oldpos);
+  if(oldfromvec == newfromvec && oldpos < newpos)
+    --newpos;
+  IGRAPH_CHECK(igraph_vector_int_insert(newfromvec, newpos, newto));
+
+  return 0;
+
+}
+
 int igraph_adjedgelist_remove_duplicate(const igraph_t *graph, 
 					igraph_inclist_t *al) {
     IGRAPH_WARNING("igraph_adjedgelist_remove_duplicate() is deprecated, use "
